==> banshee-1-0.99.1.tar.bz2: banshee-1-0.99.1/src/Core/Banshee.Services/Banshee.Database/BansheeModelCache.cs <==

//
// BansheeDatabaseModelCache.cs
//
// Author:
//   Gabriel Burt <gburt@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Data;

using Hyena.Data.Sqlite;

namespace Banshee.Database
{
    public class BansheeModelCache <T> : SqliteModelCache <T> where T : ICacheableItem, new ()
    {
        public BansheeModelCache (HyenaSqliteConnection connection,
                                  string uuid,
                                  ICacheableDatabaseModel model,
                                  BansheeModelProvider <T> provider)
            : base (connection, uuid, model, provider)
        {
        }
        
        protected override string CacheModelsTableName {
            get { return "CoreCacheModels"; }
        }
        
        protected override string CacheTableName {
            get { return "CoreCache"; }
        }
    }
}

==> banshee-1-1.9.4.tar.bz2: banshee-1-1.9.4/src/Core/Banshee.Services/Banshee.Database/BansheeModelCache.cs <==

//
// BansheeDatabaseModelCache.cs
//
// Author:
//   Gabriel Burt <gburt@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

using Hyena.Data;
using Hyena.Data.Sqlite;

namespace Banshee.Database
{
    public class BansheeModelCache <T> : SqliteModelCache <T> where T : ICacheableItem, new ()
    {
        public BansheeModelCache (HyenaSqliteConnection connection,
                                  string uuid,
                                  ICacheableDatabaseModel model,
                                  SqliteModelProvider <T> provider)
            : base (connection, uuid, model, provider)
        {
        }

        protected override string CacheModelsTableName {
            get { return "CoreCacheModels"; }
        }

        protected override string CacheTableName {
            get { return "CoreCache"; }
        }
    }
}
